@@ -1,9 +1,7 @@
 package TestApp::Controller::Js;
 
-use strict;
-use warnings;
-
-use parent 'Catalyst::Controller::Combine';
+use Moose;
+BEGIN { extends 'Catalyst::Controller::Combine'; }
 
 __PACKAGE__->config(
     depend => {
@@ -17,6 +15,4 @@ sub call_uri :Global('/call_uri') {
     $c->res->output('' . $c->uri_for($c->controller('Js')->action_for('default'), 'js1.js'));
 }
 
-
-
 1;
